@@ -7,22 +7,9 @@ from xlsx_lib.domain.frame.frame_cell_value_types import FrameCellValueTypes
 from xlsx_lib.domain.frame.frame_element import FrameElement
 from xlsx_lib.domain.xlsx_elements.sheet import Sheet
 
-
-class ModelEndError(EOFError):
-    pass
-
-
-class EmptyValueError(ValueError):
-    pass
-
-
-class ComplexFrameElementError(ValueError):
-    def __init__(
-            self,
-            jumped_rows: int,
-    ):
-        self.jumped_rows: int = jumped_rows
-        super().__init__()
+from xlsx_lib.domain.frame.complex_frame_element_error import ComplexFrameElementError
+from xlsx_lib.domain.xlsx_elements.errors.empty_value_error import EmptyValueError
+from xlsx_lib.domain.xlsx_elements.errors.sheet_end_error import SheetEndError
 
 
 def get_frame_cell_value_type(cell: Cell) -> FrameCellValueTypes:
@@ -58,13 +45,14 @@ class FrameSheet(Sheet):
 
             try:
                 self.process_cell(cell, col_index, row_index)
+                print(f"{row_index}\t\t{cell.value}")
             except EmptyValueError:
                 row_index += 1
                 continue
             except ComplexFrameElementError as error:
                 row_index += error.jumped_rows
                 continue
-            except ModelEndError:
+            except SheetEndError:
                 break
 
             row_index += 1
@@ -73,8 +61,9 @@ class FrameSheet(Sheet):
         if cell.value is None:
             if self.sheet_reader.read_cell_value(col_index, row_index + 1) is None \
                     and self.frame_elements[-1].value is None \
-                    and len(self.frame_elements[-1].element_parts) == 0 and \
-                    self.frame_elements[-1].observations is None:
+                    and self.frame_elements[-1].element_parts is not None\
+                    and len(self.frame_elements[-1].element_parts) == 0 \
+                    and self.frame_elements[-1].observations is None:
                 self.process_complex_frame_element_observations(
                     row=row_index,
                 )
@@ -97,24 +86,36 @@ class FrameSheet(Sheet):
     ) -> None:
         values: List[str] = self.sheet_reader.read_cells_values(col, col + 2, row, row)
 
-        self.frame_elements.append(FrameElement(
-            name=values[0],
-            value=values[1],
-            observations=values[2],
-        ))
+        self.frame_elements.append(
+            FrameElement(
+                name=values[0],
+                value=values[1],
+                observations=values[2],
+            )
+        )
 
     def process_element_part(
             self,
             col: int,
             row: int,
     ) -> None:
-        values: List[str] = self.sheet_reader.read_cells_values(col, col + 2, row, row)
+        values: List[str] = self.sheet_reader.read_cells_values(
+            col,
+            col + 2,
+            row,
+            row
+        )
 
-        self.frame_elements[-1].element_parts.append(ElementPart(
-            name=values[0],
-            value=values[1],
-            observations=values[2]
-        ))
+        if self.frame_elements[-1].element_parts is None:
+            self.frame_elements[-1].element_parts = list()
+
+        self.frame_elements[-1].element_parts.append(
+            ElementPart(
+                name=values[0],
+                value=values[1],
+                observations=values[2]
+            )
+        )
 
     def process_complex_frame_element_observations(
             self,
@@ -158,4 +159,4 @@ class FrameSheet(Sheet):
                                            is FrameCellValueTypes.FRAME_ELEMENT])
 
         if frame_elements_matches == 0 and element_parts_matches == 0:
-            raise ModelEndError
+            raise SheetEndError
