@@ -6,5 +6,5 @@ from xlsx_lib.domain.tightening_specifications.element_part import ElementPart
 
 
 class SpecificationElement(CamelModel):
-    name: str
+    name: Optional[str]
     parts: Optional[List[ElementPart]]
